@@ -6,7 +6,7 @@ use Carp;
 
 our $VERSION = 1.01;
 
-my %fields = map { $_ => 1 } qw(textarea text checkbox select radio checkbox_group password hidden submit);
+my %fields = map { $_ => 1 } qw(textarea text checkbox select radio checkbox_group radio_group password hidden submit);
 my %mutators    = map { $_ => 1 } qw(well_formed sticky fallback values_as_labels);
 my %accessors    = map { $_ => 1 } qw(field_object params);
 
